{
  config,
  pkgs,
  ...
}: {
  imports = [
    ../../modules/home-manager/git
    ../../modules/home-manager/nixvim
    ../../modules/home-manager/emacs
    ../../modules/home-manager/kitty
    ../../modules/home-manager/zsh
    ../../modules/home-manager/tmux
    ../../modules/home-manager/email
    ../../modules/home-manager/password-store
    ../../modules/home-manager/taskwarrior
    #../../modules/home-manager/sketchybar
    ../../modules/home-manager/kubernetes.nix
    ../../modules/home-manager/nix-index.nix
    ../../modules/home-manager/bitwarden.nix
    ../../modules/home-manager/latex.nix
    ../../modules/home-manager/ghostty.nix
  ];
  home.username = "mthomson";
  home.homeDirectory = "/Users/mthomson";
  home.stateVersion = "23.11";

  home.sessionVariables = {
    ZK_NOTEBOOK_DIR = "\${HOME}/zk";
  };

  programs = {
    direnv = {
      enable = true;
      enableZshIntegration = true;
      nix-direnv.enable = true;
    };
    zk = {
      enable = true;
      settings = {
        notebook = {
          dir = "~/zk";
        };
      };
    };
    jq = {
      enable = true;
    };
    lazygit = {
      enable = true;
    };
    man = {
      enable = true;
    };
    tealdeer = {
      enable = true;
      settings.updates.auto_update = true;
    };
    helix = {
      enable = true;
    };
    neovide = {
      enable = true;
      settings = {};
    };
    spotify-player = {
      enable = true;
    };
  };

  home.packages = with pkgs; [
    taskwarrior-tui
    sbcl
    hidden-bar
    weechat
    android-tools
    nchat
    nethack
    (pkgs.python3.withPackages (python-pkgs: with python-pkgs; [
      keyring
      click
      tldextract
    ]))
    bitwarden-cli
    nodejs
    ladybird
  ];

  programs.home-manager.enable = true;
  programs.git.enable = true;
}
